@@ -1,7 +1,3 @@
-from os.path import dirname
-from sys import path
-
-
 # dirs = dirname(__file__).replace("\\", "/").split("/")[:-1]
 # path.append("/".join(dirs))
 # dirs.append("helpful")
